@@ -320,7 +320,7 @@ linear_call <- function(x){
 
 validating_call <- function(cl){
   pure <- c("<", "<=", "==", "!=", ">=", ">", "%in%", "%vin%", "identical", "~" ,"%->%"
-          ,"grepl" ,"any_missing", "any_duplicated","var_group")
+          ,"grepl" ,"is_unique", "all_unique","is_complete","all_complete","var_group")
   unary <- c("!", "(", "all", "any" )
   binary <- c("|","||","&","&&","if","xor")
 
